summaryrefslogtreecommitdiff
path: root/sw/source/core/undo/unsort.cxx
diff options
context:
space:
mode:
Diffstat (limited to 'sw/source/core/undo/unsort.cxx')
-rw-r--r--sw/source/core/undo/unsort.cxx16
1 files changed, 8 insertions, 8 deletions
diff --git a/sw/source/core/undo/unsort.cxx b/sw/source/core/undo/unsort.cxx
index f393cfe9de2d..4399cdd1fcf7 100644
--- a/sw/source/core/undo/unsort.cxx
+++ b/sw/source/core/undo/unsort.cxx
@@ -86,11 +86,11 @@ void SwUndoSort::UndoImpl(::sw::UndoRedoContext & rContext)
SwTableNode* pTableNd = rDoc.GetNodes()[ nTableNd ]->GetTableNode();
// #i37739# A simple 'MakeFrms' after the node sorting
// does not work if the table is inside a frame and has no prev/next.
SwNode2Layout aNode2Layout( *pTableNd );
- pTableNd->DelFrms();
+ pTableNd->DelFrames();
const SwTable& rTable = pTableNd->GetTable();
SwMovedBoxes aMovedList;
@@ -110,10 +110,10 @@ void SwUndoSort::UndoImpl(::sw::UndoRedoContext & rContext)
}
// Restore table frames:
// #i37739# A simple 'MakeFrms' after the node sorting
// does not work if the table is inside a frame and has no prev/next.
const sal_uLong nIdx = pTableNd->GetIndex();
- aNode2Layout.RestoreUpperFrms( rDoc.GetNodes(), nIdx, nIdx + 1 );
+ aNode2Layout.RestoreUpperFrames( rDoc.GetNodes(), nIdx, nIdx + 1 );
}
else
{
@@ -165,11 +165,11 @@ void SwUndoSort::RedoImpl(::sw::UndoRedoContext & rContext)
SwTableNode* pTableNd = rDoc.GetNodes()[ nTableNd ]->GetTableNode();
// #i37739# A simple 'MakeFrms' after the node sorting
// does not work if the table is inside a frame and has no prev/next.
SwNode2Layout aNode2Layout( *pTableNd );
- pTableNd->DelFrms();
+ pTableNd->DelFrames();
const SwTable& rTable = pTableNd->GetTable();
SwMovedBoxes aMovedList;
@@ -193,10 +193,10 @@ void SwUndoSort::RedoImpl(::sw::UndoRedoContext & rContext)
}
// Restore table frames:
// #i37739# A simple 'MakeFrms' after the node sorting
// does not work if the table is inside a frame and has no prev/next.
const sal_uLong nIdx = pTableNd->GetIndex();
- aNode2Layout.RestoreUpperFrms( rDoc.GetNodes(), nIdx, nIdx + 1 );
+ aNode2Layout.RestoreUpperFrames( rDoc.GetNodes(), nIdx, nIdx + 1 );
}
else
{
@@ -86,11 +86,11 @@ void SwUndoSort::UndoImpl(::sw::UndoRedoContext & rContext)
SwTableNode* pTableNd = rDoc.GetNodes()[ nTableNd ]->GetTableNode();
- // #i37739# A simple 'MakeFrms' after the node sorting
+ // #i37739# A simple 'MakeFrames' after the node sorting
// does not work if the table is inside a frame and has no prev/next.
SwNode2Layout aNode2Layout( *pTableNd );
@@ -110,10 +110,10 @@ void SwUndoSort::UndoImpl(::sw::UndoRedoContext & rContext)
}
// Restore table frames:
- // #i37739# A simple 'MakeFrms' after the node sorting
+ // #i37739# A simple 'MakeFrames' after the node sorting
// does not work if the table is inside a frame and has no prev/next.
const sal_uLong nIdx = pTableNd->GetIndex();
@@ -165,11 +165,11 @@ void SwUndoSort::RedoImpl(::sw::UndoRedoContext & rContext)
SwTableNode* pTableNd = rDoc.GetNodes()[ nTableNd ]->GetTableNode();
- // #i37739# A simple 'MakeFrms' after the node sorting
+ // #i37739# A simple 'MakeFrames' after the node sorting
// does not work if the table is inside a frame and has no prev/next.
SwNode2Layout aNode2Layout( *pTableNd );
@@ -193,10 +193,10 @@ void SwUndoSort::RedoImpl(::sw::UndoRedoContext & rContext)
}
// Restore table frames:
- // #i37739# A simple 'MakeFrms' after the node sorting
+ // #i37739# A simple 'MakeFrames' after the node sorting
// does not work if the table is inside a frame and has no prev/next.
const sal_uLong nIdx = pTableNd->GetIndex();